==> nextcloud-22.2.6.tgz: nextcloud/apps/dashboard/l10n/tr.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Pano",
    "Dashboard app" : "Pano uygulaması",
    "Show something" : "Bir şeyler görüntüle",
    "Customize" : "Özelleştir",
    "Edit widgets" : "Pano bileşenlerini düzenle",
    "Get more widgets from the App Store" : "Uygulama mağazasından başka pano bileşenleri alın",
    "Change background image" : "Arka plan görselini değiştir",
    "Weather service" : "Hava durumu",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Kişisel gizliliğinizi korumak için Nextcloud sunucunuz hava durumu verilerini sizin adınıza ister. Böylece hava durumu hizmetine hiçbir kişisel bilgi aktarılmaz.",
    "Weather data from Met.no" : "Hava durumu verileri Met.no tarafından sağlanıyor",
    "geocoding with Nominatim" : "Nominatim ile coğrafi kodlama",
    "elevation data from OpenTopoData" : "yükseklik verileri OpenTopoData tarafından sağlanıyor",
    "Weather" : "Hava durumu",
    "Status" : "Durum",
    "Good morning" : "Günaydın",
    "Good morning, {name}" : "Günaydın, {name}",
    "Good afternoon" : "Tünaydın",
    "Good afternoon, {name}" : "Tünaydın, {name}",
    "Good evening" : "İyi geceler",
    "Good evening, {name}" : "İyi geceler, {name}",
    "Hello" : "Merhaba",
    "Hello, {name}" : "Merhaba {name}",
    "Pick from Files" : "Dosyalardan seçin",
    "Default images" : "Varsayılan görseller",
    "Plain background" : "Düz arka plan",
    "Insert from {productName}" : "{productName} üzerinden ekle",
    "Get more widgets from the app store" : "Uygulama mağazasından başka pano bileşenleri alın"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-23.0.9.tgz: nextcloud/apps/dashboard/l10n/tr.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Pano",
    "Dashboard app" : "Pano uygulaması",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Güne bilgilenerek başlayın\n\nNextcloud Pano, gününüzün başlangıç noktasıdır ve size yaklaşan \nrandevularınız, acil e-postalarınız, sohbet iletileri, gelen destek \nistekleri, son tweetler gibi pek çok bilgi verir! Kullanıcılar istedikleri\nbaşka pano bileşenlerini ekleyebilir ve arka planı değiştirebilir.",
    "Customize" : "Özelleştir",
    "Edit widgets" : "Pano bileşenlerini düzenle",
    "Get more widgets from the App Store" : "Uygulama mağazasından başka pano bileşenleri alın",
    "Change background image" : "Arka plan görselini değiştir",
    "Weather service" : "Hava durumu",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Kişisel gizliliğinizi korumak için Nextcloud sunucunuz hava durumu verilerini sizin adınıza ister. Böylece hava durumu hizmetine hiçbir kişisel bilgi aktarılmaz.",
    "Weather data from Met.no" : "Hava durumu verileri Met.no tarafından sağlanıyor",
    "geocoding with Nominatim" : "Nominatim ile coğrafi kodlama",
    "elevation data from OpenTopoData" : "yükseklik verileri OpenTopoData tarafından sağlanıyor",
    "Weather" : "Hava durumu",
    "Status" : "Durum",
    "Good morning" : "Günaydın",
    "Good morning, {name}" : "Günaydın, {name}",
    "Good afternoon" : "Tünaydın",
    "Good afternoon, {name}" : "Tünaydın, {name}",
    "Good evening" : "İyi geceler",
    "Good evening, {name}" : "İyi geceler, {name}",
    "Hello" : "Merhaba",
    "Hello, {name}" : "Merhaba {name}",
    "Pick from Files" : "Dosyalardan seçin",
    "Default image" : "Varsayılan görsel",
    "Plain background" : "Düz arka plan",
    "Insert from {productName}" : "{productName} üzerinden ekle",
    "Show something" : "Bir şeyler görüntüle",
    "Default images" : "Varsayılan görseller"
},
"nplurals=2; plural=(n > 1);");
